##  AI-Supported Translation
If you have permission to configure the meta model, you can use AI-supported translation to add and translate labels and help texts for new and existing attributes. This ensures that labels and help texts for fact sheet attributes are available in multiple languages. This helps create a more inclusive experience for users in different languages.. Bulk translation saves you time and effort and ensures consistency across your translated content.
To use AI-supported translation while adding a new attribute, click the Add Translations button on the Translations tab on the right-side panel. Labels and help texts in different languages are automatically generated for all the fields, field values, and relations.
![Adding Translations to Attributes Using AI-Supported Translation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2750b75f7a44101493909a1005dc2b4a_LowRes.gif)
Adding Translations to Attributes Using AI-Supported Translation
If needed, you can undo or rewrite the generated translations. For existing attributes, if a translation is missing in one or more languages, you can add the missing translations by clicking the AI Help icon and selecting the appropriate option.
![Options for Adding Missing Translations, Rewriting, or Undoing the Translation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e90cd7a4410149de99d97d21672da_LowRes.png)
Options for Adding Missing Translations, Rewriting, or Undoing the Translation
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
